==> haskell-profunctors-5.6.3-77.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 profunctors
version:              5.6.3
visibility:           public
id:                   profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
key:                  profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/profunctors/
synopsis:             Profunctors
description:          Profunctors.
category:             Control, Categories
abi:                  6c603d0620214986e4a2b2e8baade375
exposed:              True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda

import-dirs:          /usr/lib/ghc-9.6.6/site-local/profunctors-5.6.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/profunctors-5.6.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/profunctors-5.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-profunctors
hs-libraries:         HSprofunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
depends:
    base-4.18.2.1 base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL
    bifunctors-5.6.2-46LlpbtsnGiKfj3D3n0SSf
    comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    distributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html:         /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.6.3-78-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 profunctors
version:              5.6.3
visibility:           public
id:                   profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
key:                  profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/profunctors/
synopsis:             Profunctors
description:          Profunctors.
category:             Control, Categories
abi:                  1f295114dcaf74eb5d96fa8a4e69260f
exposed:              True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda

import-dirs:          /usr/lib/ghc-9.6.6/site-local/profunctors-5.6.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/profunctors-5.6.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/profunctors-5.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-profunctors
hs-libraries:         HSprofunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
depends:
    base-4.18.2.1 base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL
    bifunctors-5.6.2-A3wf66Vnx89CEVmymYgSB
    comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    distributive-0.6.2.1-GSLXrb3mYHCCnRW3oVJKQJ
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html:         /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
